@@ -29,11 +29,6 @@
 #include <gio/gio.h>
 #include <gio/gunixmounts.h>
 
-/* TODO: need to use different properties on HAL for other OS's (!) */
-#ifdef __linux__
-#define _WITH_GPHOTO2
-#endif
-
 G_BEGIN_DECLS
 
 #define G_TYPE_HAL_VOLUME_MONITOR        (g_hal_volume_monitor_get_type ())
@@ -57,13 +52,11 @@ struct _GHalVolumeMonitorClass {
 
 GType g_hal_volume_monitor_get_type (void) G_GNUC_CONST;
 
-GVolumeMonitor *g_hal_volume_monitor_new                         (void);
-GHalVolume     *g_hal_volume_monitor_lookup_volume_for_mount_path (GHalVolumeMonitor *monitor,
-                                                                   const char         *mount_path);
+GVolumeMonitor *g_hal_volume_monitor_new                          (void);
+void            g_hal_volume_monitor_force_update                 (GHalVolumeMonitor *monitor);
 
-void g_hal_volume_monitor_force_update (GHalVolumeMonitor *monitor);
+void            g_hal_volume_monitor_register                     (GIOModule         *module);
 
-void g_hal_volume_monitor_register   (GIOModule *module);
 
 G_END_DECLS
 
